@@ -1,6 +1,5 @@
 var NAVTREEINDEX7 =
 {
-"structLV__MAP__COEFF__COST.html#ac13625e52afc8b9f56490d9b4e3763c8":[13,0,89,3],
 "structLV__MAP__COEFF__COST.html#ad30ba41c53bce80c8f4c06a966a71204":[13,0,89,1],
 "structLV__MAP__EOB__COST.html":[13,0,90],
 "structLV__MAP__EOB__COST.html#a8e0e53ae7c9736000019c611ef5eb580":[13,0,90,0],
@@ -249,5 +248,6 @@ var NAVTREEINDEX7 =
 "structRefreshFrameInfo.html#aad657d56c2e3c9cb3f54a3aa9c9e1ea2":[13,0,115,1],
 "structRefreshFrameInfo.html#abda267747d6fc4a0be09eaa6b43f636c":[13,0,115,0],
 "structRefreshFrameInfo.html#af43c353c062e7a0046486cce3d82fa5f":[13,0,115,2],
-"structResizeCfg.html":[13,0,116]
+"structResizeCfg.html":[13,0,116],
+"structResizeCfg.html#a648d5bb8effb5ece1b5e7abcd4f2a197":[13,0,116,1]
 };
